
Overview
========

|                       |                                                                                    |
|-----------------------|------------------------------------------------------------------------------------|
| Build Status          | ![Build Status](https://secure.travis-ci.org/getslash/pact.png?branch=master,dev) |
| Supported Versions    | ![Supported Versions](https://img.shields.io/pypi/pyversions/pact.svg)    |
| Latest Version        | ![Latest Version](https://img.shields.io/pypi/v/pact.svg)                  |
| Test Coverage         | ![Coverage Status](https://coveralls.io/repos/getslash/pact/badge.svg?branch=master&service=github)   |


*pact* is a library implementing a general concept of promises/deferreds. It less strictly follows known standards such as A+, but rather aims to be practical for library or framework implementations.

Check out the [user's guide](http://pact.readthedocs.org/en/latest/user_guide.html ) to get started.


Licence
=======

BSD3

